@@ -2,8 +2,7 @@
 //can be changed from FF using about:config
 pref("indexdata.cf.homerepo", "https://cfrepo.indexdata.com/repo.pl");
 pref("indexdata.cf.defaulttemplate", "search.cft");
-pref("indexdata.cf.ninjaurl",
-    "http://donut.indexdata.com:8080/masterkey-test-suites/");
+pref("indexdata.cf.ninjaurl", "http://ninja.indexdata.com/metaproxytarget/");
 
 pref("indexdata.cf.ninja.searchengine", "http://ebsco1n.indexdata.com:9000/");
 //pref("indexdata.cf.logging.root", "INFO");
