@@ -16,6 +16,7 @@ var Block = function (task, name, label, parentStep) {
   this.previousBlock = null;
   this.nextBlock = null;
   this.isError = false;
+  this.isCancelled = false;
   this.name = name || null;
   this.label = label || null;
   this.parentStep = parentStep || null;
@@ -208,10 +209,16 @@ Block.prototype.seekEnd = function () {
   this.nextToRun = this.steps.length;
 };
 
+// End this iteration of the block by skipping to the end
 Block.prototype.complete = function () {
-    this.nextToRun = this.stopRunningAt;
+  this.nextToRun = this.stopRunningAt;
 };
 
+// Complete block and mark it to not be iterated
+Block.prototype.cancel = function () {
+  this.complete();
+  this.isCancelled = true;
+};
 
 Block.prototype.interrupt = function (delay, cb) {
   logger.debug( "interrupt on " + this.debugname()  );
