@@ -138,6 +138,7 @@ Task.prototype.clearItems = function () {
 
 // attaches step instance to the task
 Task.prototype.attachStep = function (step, recurse) {
+  logger.debug("Task.attachStep: step: " + step.toString() + " r=" + recurse);
   if (typeof step.isAlt == "undefined") {
     step.isAlt = false;
   }
@@ -146,10 +147,13 @@ Task.prototype.attachStep = function (step, recurse) {
   if (recurse) {
     let blocks = step.blocks;
     for (let i=0; i<blocks.length; i++) {
+      logger.debug("Task.attachStep: step: " + step.toString() + " doing block " + i);
       let b = blocks[i];
       b.task = this;
       for (let j=0; j<b.steps.length; j++) {
-        this.attachStep(b.steps[j]);
+        logger.debug("Task.attachStep: step: " + step.toString() + 
+          " recursing into sterp " + b.steps[j].toString() );        
+        this.attachStep(b.steps[j],true);
       }
     }
   }
@@ -243,6 +247,7 @@ Task.prototype._error = function (message, step) {
 Task.prototype.initRunData = function () {
   this.lastRunData = {};
   this.lastRunData.urls = {};
+  this.block.resetState();
 };
 
 Task.prototype.postprocessRunData = function () {
