@@ -9,7 +9,10 @@ Components.utils.import('resource://indexdata/thirdparty/jsonPath.js');
 Components.utils.import('resource://indexdata/util/logging.js');
 
 var logger = logging.getLogger();
-var ForEach = function () { this.conf = {}; };
+var ForEach = function () { 
+  this.isBreakable = true;
+  this.conf = {};
+};
 ForEach.prototype = new Step();
 ForEach.prototype.constructor = ForEach;
 
@@ -33,6 +36,7 @@ ForEach.prototype.resetState = function () {
 }
   
 ForEach.prototype.run = function (task, block) {
+  this.blocks[0].isCancelled = false;
   let objs = jsonPath(task.data, this.conf.source.path);
   let dest = jsonPath(task.data, this.conf.current.path)[0];
   if ( typeof(this.loopcounter) == "undefined" ) {
@@ -41,7 +45,7 @@ ForEach.prototype.run = function (task, block) {
   } else {
     logger.debug("foreach loop resuming with iteration " + this.loopcounter );
   }
-  while ( this.loopcounter < objs.length ) {
+  while ( (this.loopcounter < objs.length) && !this.blocks[0].isCancelled ) {
     dest[this.conf.current.key] = [objs[this.loopcounter]];
     logger.debug("foreach: about to run iteration " + this.loopcounter );
     this.blocks[0].run(block);
@@ -66,7 +70,7 @@ ForEach.prototype.getDescription = function () {
 };
 
 ForEach.prototype.getVersion = function () {
-  return "1.0";
+  return "1.1";
 };
 
 ForEach.prototype.getUsedArgs = function () {
