@@ -150,20 +150,6 @@ ParseXpattern.prototype.setPattern = function(patt) {
     this.editcallback(patt);
   if ( this.historycallback )
     this.historycallback(patt);
-  /*
-  if ( this.cpatt && this.cpatt.textContent != patt ) {
-    logger.debug("Updating cpatt label" );
-    this.cpatt.textContent = patt;
-    // textContent seems to make autowrap, value makes one long line.
-    // nothing seems to respect newlines that I want to put in.
-    // TODO - Refactor the update functions into the tabs, and build 
-    // a multi-line display in the create tab.
-  }
-  if ( this.epatt && this.epatt.value != patt ) {
-    logger.debug("Updating epatt display" );
-    this.epatt.value = patt;
-  }
-  */
 }; // setPattern
 
 // Helper to collect $variable names
@@ -184,7 +170,7 @@ ParseXpattern.prototype.varnamelist = function () {
 
   var jp = this.conf.jsonPath.path + "." + this.conf.jsonPath.key;
   //logger.debug("Getting jsonpath " + jp );
-  var obj = jsonPath(templ, this.conf.jp);
+  var obj = jsonPath(templ, jp);
   //logger.debug("Got jsonpath obj " + obj );
   
   if ( !obj ) {
@@ -610,7 +596,8 @@ ParseXpattern.prototype.drawCreateTab = function(surface, win, context) {
   addAltMenu(toolmenu);
   clearMenu(toolmenu);
 
-  populateDesigner();
+  populateDesigner(true);   // with autogen, so we don't get irritating popups
+     // if things go wrong. CP-3525
 
   addNodeButton.addEventListener("click", function(e) {
       selectAndAddField( nodebox, null );   // null means add to the end
@@ -1967,123 +1954,123 @@ ParseXpattern.prototype.drawHistoryTab = function (surface, context) {
   if ( !context.conf.xpatternhistory ||
        !context.conf.xpatternhistory.length ) {
     logger.debug("No history, nothing to draw");
-    return;
-    }
+  }
+  else {
+    for ( var i = 0; i < context.conf.xpatternhistory.length; i++) {
+      var patt = context.conf.xpatternhistory[i];
+      var pb = xmlHelper.appendNode(historybox, "hbox" );
+      xmlHelper.appendNode(pb,"vbox", null, { height:7}  );
+      //logger.debug("h " + i + " hist = " + historyhits[patt] );
+      if ( typeof(historyhits[patt]) == "undefined" )
+        historyhits[patt] = "Try";
+      var trybut = xmlHelper.appendNode(pb, "button", null,
+            {label: historyhits[patt], width:50 } );
+      trybut.cf_patt = patt;
+      var revertbut = xmlHelper.appendNode(pb, "button", null,
+            {label: "Revert", width:50, disabled:(i==0) } );
+      revertbut.cf_patt = patt;
 
-  for ( var i = 0; i < context.conf.xpatternhistory.length; i++) {
-    var patt = context.conf.xpatternhistory[i];
-    var pb = xmlHelper.appendNode(historybox, "hbox" );
-    xmlHelper.appendNode(pb,"vbox", null, { height:7}  );
-    //logger.debug("h " + i + " hist = " + historyhits[patt] );
-    if ( typeof(historyhits[patt]) == "undefined" )
-      historyhits[patt] = "Try";
-    var trybut = xmlHelper.appendNode(pb, "button", null,
-           {label: historyhits[patt], width:50 } );
-    trybut.cf_patt = patt;
-    var revertbut = xmlHelper.appendNode(pb, "button", null,
-           {label: "Revert", width:50, disabled:(i==0) } );
-    revertbut.cf_patt = patt;
-    
-    var l = 0;  // find the part to highlight
-    var r = patt.length-1;
-    if ( i == context.conf.xpatternhistory.length -1 ) {
-      // last one, no next to compare
-      r = 0;
-    } else { // find the difference from previous
-             // actually, find length of matching beginning and end,
-             // the rest must be the different part. Ignore whitespace
-      var prev = context.conf.xpatternhistory[i+1];
-      var pr = prev.length -1;
-      var pl = 0;
-      while ( l<patt.length && pl < prev.length) {
-        if ( patt[l] == prev[pl] ) {
-          l++;
-          pl++;
-        } else if ( patt[l].match(/\s/) ) {
-          l++;
-        } else if ( prev[pl].match(/\s/) ) {
-          pl++;
-        } else break; // found a true difference
+      var l = 0;  // find the part to highlight
+      var r = patt.length-1;
+      if ( i == context.conf.xpatternhistory.length -1 ) {
+        // last one, no next to compare
+        r = 0;
+      } else { // find the difference from previous
+              // actually, find length of matching beginning and end,
+              // the rest must be the different part. Ignore whitespace
+        var prev = context.conf.xpatternhistory[i+1];
+        var pr = prev.length -1;
+        var pl = 0;
+        while ( l<patt.length && pl < prev.length) {
+          if ( patt[l] == prev[pl] ) {
+            l++;
+            pl++;
+          } else if ( patt[l].match(/\s/) ) {
+            l++;
+          } else if ( prev[pl].match(/\s/) ) {
+            pl++;
+          } else break; // found a true difference
+        }
+        while ( l > 0 && patt[l] && patt[l].match(/[a-zA-Z0-9$]/) )
+          l--; // back to beginning of word
+        while ( r > l && pr > pl  ) {
+          if ( patt[r] == prev[pr] ) {
+            r--;
+            pr--;
+          } else if ( patt[r].match(/\s/) ) {
+            r--;
+          } else if ( prev[pr].match(/\s/) ) {
+            pr--
+          } else break;
+        }
+        while ( r<patt.length && patt[r] && patt[r].match(/[a-zA-Z0-9]/) )
+          r++; // skip to end of word
       }
-      while ( l > 0 && patt[l] && patt[l].match(/[a-zA-Z0-9$]/) )
-        l--; // back to beginning of word
-      while ( r > l && pr > pl  ) {
-        if ( patt[r] == prev[pr] ) {
-          r--;
-          pr--;
-        } else if ( patt[r].match(/\s/) ) {
-          r--;
-        } else if ( prev[pr].match(/\s/) ) {
-          pr--
-        } else break;
-      }
-      while ( r<patt.length && patt[r] && patt[r].match(/[a-zA-Z0-9]/) )
-        r++; // skip to end of word
-    }
-    xmlHelper.appendNode(pb, "label", null, 
-                { value: patt.substr(0,l),
-                  style:"margin-right: 0px; " } );
-    xmlHelper.appendNode(pb, "label", null, 
-                { value: patt.substr(l, r-l+1), 
-                         style:"margin-left: 0px; margin-right: 0px;font-weight:bold;"} );
-    xmlHelper.appendNode(pb, "label", null, 
-                         { value: patt.substr(r+1),
-                         style:"margin-left: 0px; " } );
-                         
-    revertbut.addEventListener("click", function(e) {
-      logger.debug("Revert button " + this.cf_patt );
-      context.setPattern(this.cf_patt);
-    }, false);
-          
-    trybut.addEventListener("click", function(e) {
-      logger.debug("Try button " + this.cf_patt );
-      var hits = "??";
-      var tooltip = "";
-      var task = new Task(context.task.connector, "dummy");
-      var origpatt = context.conf.xpattern;
-      try { // run the step with a fake task parameter to get the outputs
-        context.conf.xpattern = this.cf_patt;
-        context.run(task);
-        hits = "" + task.xpatternHits.length + " hit";
-        if ( task.xpatternHits.length != 1)
-          hits += "s";
-        if (task.xpatternwarnings) {
-          hits += " " + task.xpatternwarnings + "w";
-        } else { // count number of pieces in the hits
-            var pcs = 0;
-            for (var i=0; i<task.xpatternHits.length; i++) {
-              var h = task.xpatternHits[i];
-              for ( var j=0; j<h.hits.length; j++ ) {
-                if ( h.hits[j].name && h.hits[j].value )
-                  pcs++;
+      xmlHelper.appendNode(pb, "label", null,
+                  { value: patt.substr(0,l),
+                    style:"margin-right: 0px; " } );
+      xmlHelper.appendNode(pb, "label", null,
+                  { value: patt.substr(l, r-l+1),
+                          style:"margin-left: 0px; margin-right: 0px;font-weight:bold;"} );
+      xmlHelper.appendNode(pb, "label", null,
+                          { value: patt.substr(r+1),
+                          style:"margin-left: 0px; " } );
+
+      revertbut.addEventListener("click", function(e) {
+        logger.debug("Revert button " + this.cf_patt );
+        context.setPattern(this.cf_patt);
+      }, false);
+
+      trybut.addEventListener("click", function(e) {
+        logger.debug("Try button " + this.cf_patt );
+        var hits = "??";
+        var tooltip = "";
+        var task = new Task(context.task.connector, "dummy");
+        var origpatt = context.conf.xpattern;
+        try { // run the step with a fake task parameter to get the outputs
+          context.conf.xpattern = this.cf_patt;
+          context.run(task);
+          hits = "" + task.xpatternHits.length + " hit";
+          if ( task.xpatternHits.length != 1)
+            hits += "s";
+          if (task.xpatternwarnings) {
+            hits += " " + task.xpatternwarnings + "w";
+          } else { // count number of pieces in the hits
+              var pcs = 0;
+              for (var i=0; i<task.xpatternHits.length; i++) {
+                var h = task.xpatternHits[i];
+                for ( var j=0; j<h.hits.length; j++ ) {
+                  if ( h.hits[j].name && h.hits[j].value )
+                    pcs++;
+                }
               }
-            }
-            hits += " " + pcs + "p";
-            if ( task.xpatternHits.length + pcs >= 100)
-              hits = hits.replace ( / hits?/, "h" );  // shorten text to fit a button
+              hits += " " + pcs + "p";
+              if ( task.xpatternHits.length + pcs >= 100)
+                hits = hits.replace ( / hits?/, "h" );  // shorten text to fit a button
+          }
+        } catch (e) {
+          logger.debug("Trying history pattern " + this.cf_patt + " failed " +
+              "with " + e  );
+          if ( e.fileName )
+            logger.debug(" at " + e.fileName + "." + e.lineNumber );
+          if ( e.message == "No hits found" )
+            hits = "No hits";
+          else {
+            hits = "Error"; // the user can revert and see it in the editor
+            tooltip = e.message;
+          }
         }
-      } catch (e) {
-        logger.debug("Trying history pattern " + this.cf_patt + " failed " + 
-            "with " + e  );
-        if ( e.fileName )
-          logger.debug(" at " + e.fileName + "." + e.lineNumber );
-        if ( e.message == "No hits found" )
-          hits = "No hits";
-        else {
-          hits = "Error"; // the user can revert and see it in the editor
-          tooltip = e.message;
-        }
-      }
-      this.label = hits;
-      this.setAttribute("tooltiptext",tooltip);
-      historyhits[this.cf_patt] = hits;
-      context.conf.xpattern = origpatt;
-      }, false );
-    
-  } // history loop
+        this.label = hits;
+        this.setAttribute("tooltiptext",tooltip);
+        historyhits[this.cf_patt] = hits;
+        context.conf.xpattern = origpatt;
+        }, false );
 
+    } // history loop
+  } // have history
 
   var updatecallback = function(patt) {
+    //logger.debug("Updating the history with " + patt );
     var oldhist = this.conf.xpatternhistory;
     if (!oldhist) // can happen with a brand new connector
       oldhist = []; // defensive coding, anyway.
@@ -2127,6 +2114,7 @@ ParseXpattern.prototype.highlightHits = function (hitsarray) {
       p.is_collapsed = false; 
     }
   }
+  logger.debug("highlightHits: starting hit loop");
   for (var i=0; i<hitsarray.length; i++) {
     var h = hitsarray[i];
     for (var j=0; j<h.hits.length; j++) {
@@ -2145,7 +2133,6 @@ ParseXpattern.prototype.highlightHits = function (hitsarray) {
               } else {
                 xulHelper.unhighlightNode(d, false );
                 p.is_collapsed = true;
-                
               }
           }
           if ( ! p.highlight ) { // set highlight if not yet set
@@ -2163,6 +2150,7 @@ ParseXpattern.prototype.highlightHits = function (hitsarray) {
     }
   }
   // and distribute them to all hits
+  logger.debug("highlightHits: Redistributing");
   for (var i=0; i<hitsarray.length; i++) {
     var h = hitsarray[i];
     for (var j=0; j<h.hits.length; j++) {
@@ -2186,6 +2174,7 @@ ParseXpattern.prototype.highlightHits = function (hitsarray) {
       }
     }
   }
+  logger.debug("highlightHits: highlighting designer");
   if ( this.nodebox ) {
     if ( this.nodebox.firstChild )
       this.rehighlightDesignerHits( this.nodebox.firstChild );
@@ -2203,7 +2192,12 @@ ParseXpattern.prototype.rehighlightDesignerHits = function ( line ) {
     if ( line.cf_lineType == "group" ) {
       this.rehighlightDesignerHits( line.cf_contentbox.firstChild );
     } else  if ( line.cf_domNode && ! line.cf_collapsed ) {
-      xulHelper.highlightNode( line.cf_domNode, line.cf_highlight, true );
+      try {
+        xulHelper.highlightNode( line.cf_domNode, line.cf_highlight, true );
+      } catch(e) {
+        logger.debug("rehighlightDesignerHits caught an exception " + e +
+          ". Probably page has changed, so we can not highlight it");
+      }
     }
     line = line.nextSibling;
   }
@@ -2344,17 +2338,21 @@ ParseXpattern.prototype.run = function (task) {
   //dump("match returned " + hitsarray.length + " hits\n");
   if (this.inBuilder ) {
       if ( this.conf['highlighthits'] ) {
+        logger.debug("About to highlight hits in xp.run");
         this.highlightHits(hitsarray);
+        logger.debug("Done with highlight hits in xp.run");
       }
       task.xpatternHits = hitsarray; // pass to the builder
       task.parsedXpattern = xp; // remember the actual pattern tree
   }
   var resarr = [];
-  var hitnumber = undefined; 
-  if (this.conf.keephitnumber) {
-    hitnumber = parseInt(jsonPathHelper.get(this.conf["hitnumbervar"], task.data));
+  var hitnumber = undefined;
+  if ( this.conf.hitnumbercheck ) {
+    if (this.conf.keephitnumber) {
+      hitnumber = parseInt(jsonPathHelper.get(this.conf["hitnumbervar"], task.data));
+    }
+    logger.debug("Expecting to start with hitnumber " + hitnumber );
   }
-  logger.debug("Expecting to start with hitnumber " + hitnumber );
   var hitchecker = { hitnumber: hitnumber, warnings: 0, task: task };
   for (var i=0; i<hitsarray.length; i++) {
       var r = this._onehit(hitsarray[i],0, hitchecker);
