@@ -226,7 +226,7 @@ app.loadTemplate = function (file) {
     app.newConnector();
   } catch (e) {
     logger.debug(e);
-    app.popupError("Cannot open template: " + e.message);
+    app.popupError("Cannot open template: " + e.message + " in " + e.fileName + ":" + e.lineNumber);
     return;
   }
 };
@@ -284,12 +284,13 @@ app.loadFile = function (windowContext) {
         app.popupError("Cannot open file: " + e.message);
         return;
       }
+      // use test session values for builder
+      // * only on load so they persist between task invocations
+      app.connector.useSessionTestValues();
       var bWin = app.getBrowserWidget(windowContext);
-
       app.set("lastOpened", fp.file);
       app.notify("connector");
       app.set("canSave", false);
-      //taskPane.selectedTask = null;
     }, {"name" : "CF Connectors", "ext" : "*.cf"}, null, null, 'cf'
   );
 };
@@ -440,6 +441,7 @@ app.loadState = function () {
 
     app.loadTemplate(templateFile);
     app.connector.loadConf(parser.parseFromString(connectorString, "text/xml"));
+    app.connector.useSessionTestValues();
     app.set("canSave", canSave);
     app.set("lastOpened", lastOpened);
     app.notify("connector");
