@@ -459,7 +459,13 @@ Xpattern.prototype.dumpString = function ( indent ) {
   var assign="";
   if (this.attrValue) {
       relation = this.relationValue ? this.relationValue : "=";
-      assign = " " + relation + " \"" + this.attrValue + "\"";
+      // both / and " are valid quotes here.
+      // prefer / for regexp, but only if the value does not contain such
+      // so we can have a URL there
+      var attrquote = '"';
+      if ( relation == "~" && !this.attrValue.match(/\//) )
+        attrquote = "/";
+      assign = " " + relation + attrquote + this.attrValue + attrquote;
   }
 
   var variable = "";
