@@ -37,8 +37,7 @@ do
       if [ ! -z "$QRY" ]
       then 
         zoomsh "connect localhost:9070" "set databaseName $CONNECTOR" \
-                  "search $QRY" \
-                  "show 0 1" "show 1 1" "quit" >>$LOG
+                  "set count 2" "search $QRY" "quit" >>$LOG
         test $? -ne 0 && RET=1
       fi
     done < $QRYFILE
