@@ -17,7 +17,6 @@
 #include <errno.h>
 #include <sys/types.h>
 #include <sys/stat.h>
-#include <pwd.h>
 #include <signal.h>
 #include "cf_display.h"
 #include <yaz/nmem.h>
@@ -95,15 +94,6 @@ bool CF_Display::lock(int log_fd)
 
         wrbuf_puts(lockdir, display_lock);
 
-        uid_t euid = geteuid();
-        char buf[2048];
-        struct passwd pw1, *pw = 0;
-        getpwuid_r(euid, &pw1, buf, sizeof(buf), &pw);
-        if (pw)
-        {
-            wrbuf_puts(lockdir, "-");
-            wrbuf_puts(lockdir, pw->pw_name);
-        }
         if (display_start_str && *display_start_str)
             display_start = atoi(display_start_str);
 
