@@ -34,7 +34,7 @@ public:
              CF_Logger *logger, int fd);
     ~CF_Embed();
     bool spawn_thread(std::string &err_msg);
-    bool spawn_fork(std::string &err_msg, int fd);
+    bool spawn_fork(std::string &err_msg, int fd, int capt_stdout);
     const char *get_module_path();
     const char *get_app_path();
     void main();
@@ -52,7 +52,7 @@ public:
     bool run_tests_parent(const char *task_order);
     bool unit_test_parent(const char *name);
     CF_Logger *logger; // passed logger in constructor or itself
-    void printf(const char *level, const char *fmt, ...);
+    void printf(const char *module, int level, const char *fmt, ...);
 private:
     bool wait_init_handshake(std::string &error_msg);
     void copy_initial_js_files(const char *a_profile_path,
