@@ -76,7 +76,7 @@ int main(int argc, char **argv)
     CF_Engine *e = 0;
     try
     {
-        e = cf_factory.create(flags, cf_proxy, cf_loglevel, 0, -1);
+        e = cf_factory.create(flags, cf_proxy, cf_loglevel, 0, -1, 1);
 
 	if (cf_file)
 	    e->load_cf(cf_file);
