@@ -1,5 +1,5 @@
 /* This file is part of the Connector Framework
- * Copyright (C) 2008-2012 Index Data
+ * Copyright (C) 2008-2013 Index Data
  * See the file LICENSE for details.
  */
 
@@ -12,7 +12,8 @@
 
 int cf_database_args(const char *url_arg,
                      ODR odr,
-                     char **subdatabase, const char **proxy,
+                     char **subdatabase,
+                     const char **proxy, const char **loglevel,
                      WRBUF result,
                      const char *default_user,
                      const char *default_password);
