@@ -562,7 +562,14 @@ void yf::CF::Rep::expire(void)
     while (true)
     {
         boost::xtime xt;
-        boost::xtime_get(&xt, boost::TIME_UTC);
+        boost::xtime_get(&xt,
+#if BOOST_VERSION >= 105000 
+                boost::TIME_UTC_
+#else
+                boost::TIME_UTC
+#endif
+                  );
+
         xt.sec += 60;
         boost::thread::sleep(xt);
 
